Aydin Use-Cases, and the Art & Science of Image Denoising.
===========================================================

While designing Aydin, we came to the realisation that ‘image denoising’ is not a single problem,
but a multiplicity of different challenges each one requiring a different yet related solution.
There are many different kinds of image noises and related degradations and it requires a lot of
know-how to both understand this diversity and tackle these different kinds of noises. This
diversity comes from the inherent diversity of imaging modalities: different instruments, optics,
detectors, contrast mechanisms, photo-chemistry, etc… This extends well beyond just optical
images but is also essentially true for any mechanism that generates images and more generally
any multi-dimensional array-like measurement.

The uses cases presented below are the ideal starting point for people so you can understand
the different kinds of noise that affect your images and first we start with some simple
photographs with different types of noises, some typical and realistic and some other more
academic but not less insightful and didactic.

#. `Denoising Basics with Aydin <basics.html>`_
#. `Denoising Spinning-Disk Confocal Microscopy Images with Aydin <confocal.html>`_
